@@ -67,7 +67,7 @@ grey_button_cb (GtkWidget *entry, gpointer data)
 	{
 		w = GTK_WIDGET (current->data);
 
-		if (!GTK_WIDGET_IS_SENSITIVE (w))
+		if (!gtk_widget_is_sensitive (w))
 			continue;
 
 		text = gtk_editable_get_chars (GTK_EDITABLE (w), 0, -1);
@@ -1046,7 +1046,7 @@ link_response_cb (GtkWidget *widget, gint arg, gpointer data)
 	{
 		text = gtk_editable_get_chars (GTK_EDITABLE (dc->link_text), 0, -1);
 
-		if (GTK_WIDGET_SENSITIVE (dc->link_url))
+		if (gtk_widget_is_sensitive (dc->link_url))
 		{
 			link = gtk_editable_get_chars (GTK_EDITABLE (dc->link_url), 0, -1);
 			/* Check for a protocol in there somewhere... */
@@ -1059,7 +1059,7 @@ link_response_cb (GtkWidget *widget, gint arg, gpointer data)
 					"<a href=\"http://%s\">%s</a>",
 					link, text);
 		}
-		else if (GTK_WIDGET_SENSITIVE (dc->link_user))
+		else if (gtk_widget_is_sensitive (dc->link_user))
 		{
 			link = gtk_editable_get_chars (GTK_EDITABLE (dc->link_user), 0, -1);
 			insert = g_strdup_printf (
@@ -1326,7 +1326,7 @@ display_save_dialog_proceed (DrivelClient *dc)
 			GTK_WINDOW (dc->current_window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_WARNING,
-			GTK_BUTTONS_NONE,
+			GTK_BUTTONS_NONE, "%s", 
 			msg);
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog), GTK_STOCK_NO,
 			GTK_RESPONSE_REJECT,
@@ -1362,7 +1362,7 @@ display_save_dialog_close (DrivelClient *dc)
 			GTK_WINDOW (dc->current_window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_WARNING,
-			GTK_BUTTONS_NONE,
+			GTK_BUTTONS_NONE, "%s",
 			msg);
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 			GTK_STOCK_NO, GTK_RESPONSE_REJECT,
